@@ -12,7 +12,6 @@
 # language governing permissions and limitations under the License.
 
 import re
-
 from awscli.customizations.commands import BasicCommand
 from awscli.customizations.emr import applicationutils
 from awscli.customizations.emr import argumentschema
@@ -37,6 +36,8 @@ class CreateCluster(Command):
     ARG_TABLE = [
         {'name': 'release-label',
          'help_text': helptext.RELEASE_LABEL},
+        {'name': 'os-release-label',
+         'help_text': helptext.OS_RELEASE_LABEL},
         {'name': 'ami-version',
          'help_text': helptext.AMI_VERSION},
         {'name': 'instance-groups',
@@ -128,7 +129,10 @@ class CreateCluster(Command):
          'help_text': helptext.MANAGED_SCALING_POLICY},
         {'name': 'placement-group-configs',
          'schema': argumentschema.PLACEMENT_GROUP_CONFIGS_SCHEMA,
-         'help_text': helptext.PLACEMENT_GROUP_CONFIGS}
+         'help_text': helptext.PLACEMENT_GROUP_CONFIGS},
+        {'name': 'auto-termination-policy',
+         'schema': argumentschema.AUTO_TERMINATION_POLICY_SCHEMA,
+         'help_text': helptext.AUTO_TERMINATION_POLICY}
     ]
     SYNOPSIS = BasicCommand.FROM_FILE('emr', 'create-cluster-synopsis.txt')
     EXAMPLES = BasicCommand.FROM_FILE('emr', 'create-cluster-examples.rst')
@@ -197,6 +201,10 @@ class CreateCluster(Command):
             params, 'AdditionalInfo', parsed_args.additional_info)
         emrutils.apply_dict(params, 'LogUri', parsed_args.log_uri)
 
+        if parsed_args.os_release_label is not None:
+            emrutils.apply_dict(params, 'OSReleaseLabel',
+                parsed_args.os_release_label)
+
         if parsed_args.log_encryption_kms_key_id is not None:
             emrutils.apply_dict(params, 'LogEncryptionKmsKeyId',
                 parsed_args.log_encryption_kms_key_id)
@@ -357,6 +365,11 @@ class CreateCluster(Command):
                 params, 'PlacementGroupConfigs',
                 parsed_args.placement_group_configs)
 
+        if parsed_args.auto_termination_policy is not None:
+            emrutils.apply_dict(
+                params, 'AutoTerminationPolicy',
+                parsed_args.auto_termination_policy)
+
         self._validate_required_applications(parsed_args)
 
         run_job_flow_response = emrutils.call(
