@@ -48,13 +48,25 @@ HBASE_BACKUP_VERSION = (
 # create-cluster options help text
 
 CREATE_CLUSTER_DESCRIPTION = (
-    'Creates an Amazon EMR cluster with the specified configurations.\n'
-    '\nQuick start:\n'
-    '\naws emr create-cluster --release-label <release-label>'
-    ' --instance-type <instance-type> --instance-count <instance-count>\n'
-    '\nValues for the following can be set in the AWS CLI'
-    ' config file using the "aws configure set" command: --service-role, --log-uri,'
-    ' and InstanceProfile and KeyName arguments under --ec2-attributes.')
+    '<p>Creates an Amazon EMR cluster with the specified configurations.</p>'
+    '<p>Quick start:</p>'
+    '<p><code>aws emr create-cluster --release-label <release-label>'
+    ' --instance-type <instance-type> --instance-count <instance-count></code></p>'
+    '<p>Values for the following can be set in the AWS CLI'
+    ' config file using the <code>aws configure set</code> command: <code>--service-role, --log-uri,'
+    ' and InstanceProfile and KeyName arguments under --ec2-attributes</code>.</p>')
+
+DESCRIBE_CLUSTER_DESCRIPTION = (
+    '<p>Provides  cluster-level details including status, hardware'
+    ' and software configuration, VPC settings, bootstrap'
+    ' actions, instance groups and so on.</p>'
+    '<p>Permissions needed for describe-cluster include:'
+    '<ul><li><code>elasticmapreduce:ListBootstrapActions</code></li>'
+    '<li><code>elasticmapreduce:ListInstanceFleets</code></li>'
+    '<li><code>elasticmapreduce:DescribeCluster</code></li>'
+    '<li><code>elasticmapreduce:ListInstanceGroups</code></li></ul>'
+    'For information about the cluster'
+    ' steps, see <code>list-steps</code>.</p>')
 
 CLUSTER_NAME = (
     '<p>The name of the cluster. If not provided, the default is "Development Cluster".</p>')
@@ -113,6 +125,11 @@ RELEASE_LABEL = (
     ' and later. Use <code>--ami-version</code> for earlier versions.'
     ' You cannot specify both a release label and AMI version.</p>')
 
+OS_RELEASE_LABEL = (
+    '<p>Specifies a particular Amazon Linux release for all nodes in a cluster'
+    ' launch request. If a release is not specified, EMR uses the latest validated' 
+    ' Amazon Linux release for cluster launch.</p>')
+
 CONFIGURATIONS = (
     '<p>Specifies a JSON file that contains configuration classifications,'
     ' which you can use to customize applications that Amazon EMR installs'
@@ -205,7 +222,8 @@ INSTANCE_COUNT = (
     ' are used for the core node type.</p>')
 
 ADDITIONAL_INFO = (
-    '<p>Specifies additional information during cluster creation.</p>')
+    '<p>Specifies additional information during cluster creation. To set development mode when starting your EMR cluster,'
+    ' set this parameter to <code>{"clusterType":"development"}</code>.</p>')
 
 EC2_ATTRIBUTES = (
     '<p>Configures cluster and Amazon EC2 instance configurations. Accepts'
@@ -260,14 +278,13 @@ SCALE_DOWN_BEHAVIOR = (
     ' terminate EC2 instances at the instance-hour boundary, regardless of when'
     ' the request to terminate was submitted.</li>'
 )
+
 VISIBILITY = (
-    '<p>Specifies whether the cluster is visible to all IAM users of'
-    ' the AWS account associated with the cluster. If set to'
-    ' <code>--visible-to-all-users</code>, all IAM users of that AWS account'
-    ' can view it. If they have the proper policy permissions set, they can '
-    ' also manage the cluster. If it is set to <code>--no-visible-to-all-users</code>,'
-    ' only the IAM user that created the cluster can view and manage it. '
-    ' Clusters are visible by default.</p>')
+    '<p>Specifies whether the cluster is visible to all IAM users'
+    ' of the AWS account associated with the cluster. If a user'
+    ' has the proper policy permissions set, they can also manage the cluster.</p>'
+    '<p>Visibility is on by default. The <code>--no-visible-to-all-users</code> option'
+    ' is no longer supported. To restrict cluster visibility, use an IAM policy.</p>')
 
 DEBUGGING = (
     '<p>Specifies that the debugging tool is enabled for the cluster,'
@@ -485,3 +502,9 @@ PLACEMENT_GROUP_CONFIGS = (
     'passing <code>--placement-group-configs InstanceRole=MASTER</code> '
     'during cluster creation.</p>'
 )
+
+AUTO_TERMINATION_POLICY = (
+    '<p>Auto termination policy for an Amazon EMR cluster. '
+    'The configuration specifies the termination idle timeout'
+    'threshold for an cluster.</p> '
+)
